package cmd

import (
	"errors"
	"fmt"

	"git.faercol.me/faercol/polyculeconnect/polyculeconnect/cmd/utils"
	"git.faercol.me/faercol/polyculeconnect/polyculeconnect/services/backend"
	"github.com/dexidp/dex/storage"
	"github.com/spf13/cobra"
)

var backendRemoveCmd = &cobra.Command{
	Use:   "remove <backend_id>",
	Short: "Remove a backend",
	Long: `Remove the backend with the given ID from the database.

If the backend is not found in the database, no error is returned`,
	Args: cobra.ExactArgs(1),
	Run: func(cmd *cobra.Command, args []string) {
		removeBackend(args[0])
	},
}

func removeBackend(backendID string) {
	s := utils.InitStorage(utils.InitConfig(""))

	if err := backend.New(s).RemoveBackend(backendID); err != nil {
		if !errors.Is(err, storage.ErrNotFound) {
			utils.Failf("Failed to remove backend: %s", err.Error())
		}
	}
	fmt.Println("Backend deleted")
}

func init() {
	backendCmd.AddCommand(backendRemoveCmd)
}
